import { CommonModule } from '@angular/common';
import { ChangeDetectionStrategy, Component, OnInit, inject, ChangeDetectorRef } from '@angular/core';
import { Router } from '@angular/router';
import { AuthService } from '../../../../../shared/data-access/service/auth.service';
import { Observable } from 'rxjs';
import { AuthState } from '../../../../../shared/data-access/interface/auth.interface';

@Component({
  selector: 'meu-header',
  standalone: true,
  imports: [CommonModule],
  templateUrl: './header.component.html',
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class HeaderComponent implements OnInit {
  private authService = inject(AuthService);
  private router = inject(Router);
  private cdr = inject(ChangeDetectorRef);

  authState$: Observable<AuthState> = this.authService.authState$;
  isLoggingOut = false;

  ngOnInit(): void {}

  onLogout(): void {
    if (this.isLoggingOut) return;
    
    this.isLoggingOut = true;
    this.cdr.markForCheck();

    this.authService.logout().subscribe({
      next: () => {
        this.router.navigate(['/login']);
      },
      error: (error) => {
        // Even if API fails, redirect to login
        this.router.navigate(['/login']);
      },
      complete: () => {
        this.isLoggingOut = false;
        this.cdr.markForCheck();
      }
    });
  }
}
